self.__BUILD_MANIFEST=function(s,c,a,e,t,u,n,b,i,o,j,r,k,f){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-bbfee9b059a805b6.js"],"/_error":["static/chunks/pages/_error-6ae619510b1539d6.js"],"/clusters":["static/chunks/pages/clusters-c5cec158c05e5ea8.js"],"/clusters/[cluster]":[s,b,a,i,t,c,e,o,u,j,n,r,k,"static/chunks/871-3a5386132715b78e.js","static/chunks/pages/clusters/[cluster]-b724f1763fdac967.js"],"/clusters/[cluster]/[job]":[s,c,u,f,"static/chunks/pages/clusters/[cluster]/[job]-f32e27810cd539cd.js"],"/config":["static/chunks/pages/config-84a73b45c1311178.js"],"/infra":["static/chunks/pages/infra-51a43354278bcdce.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-74e9cad90e75708b.js"],"/jobs":["static/chunks/pages/jobs-424fa518aa1b5392.js"],"/jobs/pools/[pool]":[s,a,t,"static/chunks/821-781977113952dbf3.js",c,e,n,"static/chunks/pages/jobs/pools/[pool]-2dab3a17dbce7912.js"],"/jobs/[job]":[s,a,t,c,e,f,"static/chunks/pages/jobs/[job]-d1d5dc65c0c7ba59.js"],"/plugins/[...slug]":[s,"static/chunks/pages/plugins/[...slug]-56da36e2577d1df1.js"],"/users":["static/chunks/pages/users-a7e764a7c96ad24b.js"],"/volumes":["static/chunks/pages/volumes-92957590ddfbbaa7.js"],"/workspace/new":["static/chunks/pages/workspace/new-ea137ebf17f314b1.js"],"/workspaces":["static/chunks/pages/workspaces-18a4b0522d36a8e0.js"],"/workspaces/[name]":[s,b,a,i,c,e,o,u,j,n,r,k,"static/chunks/50-f9db8bee2183be2c.js","static/chunks/pages/workspaces/[name]-ec19f1c4f2163345.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/plugins/[...slug]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/739-ce131cf092b994c8.js","static/chunks/850-0b979d5ca596d640.js","static/chunks/798-c0525dc3f21e488d.js","static/chunks/969-27ac693279216e29.js","static/chunks/754-cfc5d4ad1b843d29.js","static/chunks/676-74ccbdc51f1659d7.js","static/chunks/248-613c2f7c8d45b60f.js","static/chunks/82-c5786ea3f4496d60.js","static/chunks/835-6242063df6081b97.js","static/chunks/990-91b4b5bea46084f1.js","static/chunks/43-6e5b2e5711b823b4.js","static/chunks/353-6a10d47ddaf7175f.js","static/chunks/109-7ea49fa02e7d7477.js","static/chunks/777-269d7cfa149867b9.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();